@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.117';
+our $VERSION = '0.118';
 use 5.006;
 use strict;
 use warnings;
@@ -94,8 +94,8 @@ sub _build_terse {
 		my ($self, $sid, $content, $status) = @_;
 		my $res = $self->request->new_response($self->response->{status_code} ||= $status);
 		$res->cookies($self->cookies) if $self->cookies;
-		$res->headers($self->headers) if $self->headers;
-		$res->cookies->{sid} = $sid if $sid;
+		$res->headers({%{$self->headers}}) if $self->headers;
+		$res->cookies->{sid} = {%{$sid}} if $sid;
 		$res->content_type($content);
 		return $res;
 	} unless $t->{_build_response};
@@ -372,7 +372,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.117
+Version 0.118
 
 =cut
 
