@@ -85,7 +85,7 @@ sub _load_modules {
 	my $type = $args{type};
 	$args{path} =~ s/([^\/]+)$/$args{lib}\/$1/ if ($args{lib});
 	my @modules = map {
-		(my $m = $_) =~ s/\.pm$//ig;
+		(my $m = $_) =~ s/^(\/)|(\.pm)$//ig;
 		$m =~ s/\//::/g;
 		[
 			"$args{path}/${type}/${_}",
@@ -97,7 +97,7 @@ sub _load_modules {
 		eval {
 			require $module->[0];
 		};
-		$self->raiseError($@) && die $@ if $@;
+		die $@ if $@;
 		$module = $module->[1]->new(app => 1);
 		die $@ && next if $@;
 		$mods{_alias} = { %{$mods{_alias} || {}}, %{$Terse::Controller::dispatcher{ref $module}{_alias} || {}} }; 
@@ -122,8 +122,7 @@ sub _recurse_directory {
 	for (readdir $d) {
 		next if $_ =~ m/^\./;
 	 	if (-d "$dir/$_") {
-			$path .= "/$_" if $path;
-			push @files, $self->_recurse_directory("$dir/$_", $path || $_);
+			push @files, $self->_recurse_directory("$dir/$_", ($path || "") . "/$_");
 		} elsif ($_ =~ m/\.pm/) {
 			push @files, $path ? "$path/$_" : $_;
 		}
@@ -170,7 +169,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.117
+Version 0.118
 
 =cut
 
