@@ -145,7 +145,7 @@ sub delayed_response_handle {
 		$response = eval { $response->($writer); };
 		if ($@ || $t->response->error) {
 			$res->[0] = $t->response->status_code || 500;
-			$t->raiseError($@) if $@;
+			$t->raiseError($@) if #@;
 			push @{$res}, [$t->response->serialize];
 			return $responder->($res);
 		}
@@ -178,7 +178,7 @@ sub response_handle {
 	my ($content_type, $body) = $self->views->{$t->response_view || $self->response_view} 
 		? $t->view($t->response_view || $self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
-	$body = undef if $response_body->error && $response_body->no_response;  
+	$body = undef if $response_body->error && $response_body->no_response;
 	$res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
 	$res->body($body) if $body;
 	return $res->finalize;
@@ -259,7 +259,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.117
+Version 0.118
 
 =cut
 
